@@ -10,17 +10,21 @@ def id_generator(size=6, chars=string.ascii_uppercase + string.digits):
     return ''.join(random.choice(chars) for _ in range(size))
 
 
-def generate_id(path, dir=False, **kwargs):
+def default_rsuffix(suffix):
+    return suffix
+
+
+def generate_id(path, dir=False, rsuffix=default_rsuffix, **kwargs):
     file = path.stem
     parent_path = path.parent
-    suffix = path.suffix
+    suffix = rsuffix(path.suffix)
     id = ''
     while (parent_path / f'{file}{id}{suffix}').is_dir() if dir else (parent_path / f'{file}{id}{suffix}').is_file():
         id = id_generator(**kwargs)
     return f'{file}{id}{suffix}'
 
 
-def io_mkdir(path, m='', **kwargs):
+def io_mkdir(path, **kwargs):
     if path is None:
         raise ValueError
 
@@ -30,12 +34,11 @@ def io_mkdir(path, m='', **kwargs):
     return
 
 
-def io_writer(path, data=None, m='', **kwargs):
+def io_writer(path, filename='', data=None, m='', **kwargs):
     if path is None:
         raise ValueError
 
     path = Path(path)
-    fname = ''
     if data is None:
         raise ValueError
     if type(data) is str:
@@ -54,16 +57,16 @@ def io_writer(path, data=None, m='', **kwargs):
         else:
             raise ValueError
         if not (not hasattr(data, 'name') or data.name is None or data.name == ''):
-            fname = data.name
-        else:
-            if not path.is_dir():
-                fname = path.name
+            if filename == '':
+                filename = data.name
         data = data.read()
 
-    name = generate_id(path / fname, **kwargs)
+    if filename == '':
+        filename = 'unnamed'
+    name = generate_id(path / filename, **kwargs)
 
     if m == '':
         m = mo
-    with open((path.parent / name) if fname == '' else (path / fname), m) as file:
+    with open((path / name), m) as file:
         file.write(data)
     return
